---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "constellation_attestation Data Source - constellation"
subcategory: ""
description: |-
  The data source to fetch measurements from a configured cloud provider and image.
---

# constellation_attestation (Data Source)

The data source to fetch measurements from a configured cloud provider and image.

## Example Usage

```terraform
data "constellation_attestation" "test" {
  csp                 = "aws"
  attestation_variant = "aws-sev-snp"
  image_version       = "v2.13.0"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `attestation_variant` (String) Attestation variant the image should work with. Can be one of:
  * `aws-sev-snp`
  * `aws-nitro-tpm`
  * `azure-sev-snp`
  * `gcp-sev-es`
- `csp` (String) CSP (Cloud Service Provider) to use. (e.g. `azure`)
See the [full list of CSPs](https://docs.edgeless.systems/constellation/overview/clouds) that Constellation supports.

### Optional

- `image_version` (String) The image version to use. If not set, the provider version value is used.
- `insecure` (Boolean) DON'T USE IN PRODUCTION Skip the signature verification when fetching measurements for the image.
- `maa_url` (String) For Azure only, the URL of the Microsoft Azure Attestation service

### Read-Only

- `attestation` (Attributes) Attestation comprises the measurements and SEV-SNP specific parameters. (see [below for nested schema](#nestedatt--attestation))

<a id="nestedatt--attestation"></a>
### Nested Schema for `attestation`

Read-Only:

- `amd_root_key` (String)
- `azure_firmware_signer_config` (Attributes) (see [below for nested schema](#nestedatt--attestation--azure_firmware_signer_config))
- `bootloader_version` (Number)
- `measurements` (Attributes Map) (see [below for nested schema](#nestedatt--attestation--measurements))
- `microcode_version` (Number)
- `snp_version` (Number)
- `tee_version` (Number)
- `variant` (String) Attestation variant the image should work with. Can be one of:
  * `aws-sev-snp`
  * `aws-nitro-tpm`
  * `azure-sev-snp`
  * `gcp-sev-es`

<a id="nestedatt--attestation--azure_firmware_signer_config"></a>
### Nested Schema for `attestation.azure_firmware_signer_config`

Read-Only:

- `accepted_key_digests` (List of String)
- `enforcement_policy` (String)
- `maa_url` (String)


<a id="nestedatt--attestation--measurements"></a>
### Nested Schema for `attestation.measurements`

Read-Only:

- `expected` (String)
- `warn_only` (Boolean)
